==> tor-0.1.1.25.tar.gz: tor-0.1.1.25/doc/website/tor-switchproxy.html.pl <==
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN" "http://www.w3.org/TR/REC-html40/loose.dtd">
<html>
<head>
  <title>Tor: Instrukcje do instalacji SwitchProxy</title>
  <meta name="Author" content="Roger Dingledine">
  <meta http-equiv="content-type" content="text/html; charset=UTF-8">
  <link rel="stylesheet" type="text/css" href="../stylesheet.css">
  <link rel="shortcut icon" type="image/x-icon" href="../favicon.ico">
</head>
<body>
<div class="center">
<table class="banner" border="0" cellpadding="0" cellspacing="0" summary="">
    <tr>
        <td class="banner-left"></td>
        <td class="banner-middle">
	<a href="../index.html.pl">Strona główna</a>
<a href="../overview.html.pl">Wprowadzenie</a>
<a href="../download.html.pl">Pobieranie plików</a>
<a href="../documentation.html.pl">Dokumentacja</a>
<a href="../volunteer.html.pl">Wolontariusze</a>
<a href="../people.html.pl">Ludzie</a>
<a href="../donate.html.pl">Dotacje</a>
        </td>
        <td class="banner-right">
	<img src="../images/green-flagspace.png" alt="" width="24" height="16"> <a href="tor-switchproxy.html.en"><acronym title="English"><img src="../images/en.png" alt="English" width="24" height="16"></acronym></a> <img src="../images/green-flagspace.png" alt="" width="24" height="16"> <img src="../images/green-flagspace.png" alt="" width="24" height="16"> <a href="tor-switchproxy.html.it"><acronym title="Italiano"><img src="../images/it.png" alt="Italiano" width="24" height="16"></acronym></a> <img src="../images/green-flagspace.png" alt="" width="24" height="16"> <acronym title="polski"><img src="../images/pl.png" alt="polski" width="24" height="16"></acronym> <img src="../images/green-flagspace.png" alt="" width="24" height="16"> <img src="../images/green-flagspace.png" alt="" width="24" height="16"> <img src="../images/green-flagspace.png" alt="" width="24" height="16">
        </td>
    </tr>
</table>
<div class="center">
<div class="main-column">
<p>Uwaga: SwitchProxy już nie jest polecanym rozszerzeniem do
 używania Tor'a w Firefox'ie. <b>Zamiast tego, powinieneś używać rozszerzenia <a
 href="http://freehaven.net/~squires/torbutton/">Torbutton</a>.</b>
 Zostawimy instrukcje do SwitchProxy dla tych, którzy wolą starszy
 (trudniejszy) sposób lub którzy mają bardziej złożone potrzeby, jak np.
 uruchamianie Tor'a na innym komputerze niż Firefox.</p>
<h1>Instalowanie SwitchProxy do współpracy z <a href="../index.html.pl">Tor'em</a></h1>
<hr>
<p>
SwitchProxy jest rozszerzeniem dla Firefox'a, które ułatwia przełączanie
 się między używaniem serwera Proxy a bezpośrednim łączeniem się ze
 stronami WWW.</p>
<p>Dzięki temu dokumentowi ustawisz SwitchProxy tak, by umożliwiało
 przełączanie się między używaniem Tor'a a połączeniem bezpośrednim.
 Zakładamy, że masz zainstalowanego i działającego Firefox'a.</p>
<p>Te zrzuty ekranu są dla użytkowników systemu Windows, ale
 SwitchProxy działa wszędzie tam, gdzie działa Firefox. Mamy nadzieję, że
 inni użytkownicy bez problemu będą nadążać.</p>
<hr>
<a id="zero"></a>
<h2><a class="anchor" href="#zero">Krok 0: Pobierz i zainstaluj Tor'a i Privoxy</a></h2>
<br>
<p>Zanim zaczniesz, musisz upewnić się, że 1) Tor jest uruchomiony i działa
 2) Privoxy jest uruchomione i działa, i 3) Privoxy jest skonfigurowane by
 używać Tor'a.</p>
<p>Użytkownicy Windows muszą wykonać <a
 href="../docs/tor-doc-win32.html.pl#installing">krok 1</a>
 w opisie instalacji Tor'a dla Windows, a użytkownicy MAC OS X muszą wykonać <a
 href="../docs/tor-doc-osx.html.pl#installing">krok 1</a>
 w opisie instalacji Tor'a dla MAC OS X, gdyż nasze paczki dla Win32 i OS X
 zawierają Privoxy i jest już ono skonfigurowane. Użytkownicy Linux/BSD/Unix powinni wykonać <a
 href="../docs/tor-doc-unix.html.pl#installing">krok 1</a>
 i <a href="../docs/tor-doc-unix.html.pl#privoxy">krok
 2</a> w opisie instalacji Tor'a dla systemów Unix.
</p>
<hr>
<a id="one"></a>
<h2><a class="anchor" href="#one">Krok 1: Pobranie i instalacja SwitchProxy</a></h2>
<br>
<p>SwitchProxy jest rozszerzeniem do Firefox'a, więc musisz przejść przez
 proces instalacji nowego rozszerzenia. Najpierw przejdź na stronę <a
 href="https://addons.mozilla.org/addon.php?id=125">SwitchProxy</a>.
 Na chwilę włącz JavaScript i kliknij "Instaluj" ("Install Now"):</p>
<img alt="Strona WWW SwitchProxy"
src="../img/screenshot-switchproxy-webpage.jpg" width="698" height="527">
<p>Pojawi się okno z prośbą o pozwolenie instalacji rozszerzenia. Kliknij
 przycisk "Zainstaluj":
</p>
<img alt="Ostrzeżenie przed instalacją rozszerzenia w Firefox'ie"
src="../img/screenshot-switchproxy-plugin-starting.jpg" width="405" height="359">
<p>Gdy instalator skończył pracę zamknij wszystkie okna Firefox'a i
 ponownie go uruchom.</p>
<img alt="Zakończenie instalacji roszerzenia"
src="../img/screenshot-switchproxy-plugin-finished.jpg" width="450" height="171">
<hr>
<a id="two"></a>
<h2><a class="anchor" href="#two">Krok 2: Konfiguracja SwitchProxy</a></h2>
<br>
<p>Po ponownym uruchomieniu Firefox'a zauważysz nowy pasek narzędzi, który
 pozwala na kontrolę serwerów Proxy. Teraz ustawimy konfigurację Proxy dla
 Tor'a. Kliknij "Dodaj" ("Add") na nowym pasku narzędzi Proxy:</p>
<img alt="Nowy pasek narzędzi"
src="../img/screenshot-switchproxy-toolbar.jpg" width="651" height="535">
<p>Zostaniesz zapytany o typ serwera proxy. Wybierz "Standardowy".
 (Jest też typ "anonimowy", który używa istniejących anonimowych serwerów proxy.
 Nie używaj tego typu, gdyż te inne "anonimowe" serwery proxy <a
 href="http://wiki.noreply.org/noreply/TheOnionRouter/TorFAQ#ComparisonProxyAggregators">dają
 o wiele gorsze zabezpieczenia niż Tor</a>.)
</p>
<img alt="Standardowe proxy"
src="../img/screenshot-switchproxy-proxytype.jpg" width="309" height="208">
<p>Teraz zobaczysz standardowe okno konfiguracji serwerów proxy w Firefox'ie.
 Nadaj tej konfiguracji nazwę (etykietę) "tor". Potem wpisz "localhost" i
 "8118" do czterech pierwszych protokołów, by skierować je na Privoxy, jak
 pokazano. (Nawet mimo iż Privoxy nie obsluguje FTP i Gophera, <a
 href="http://wiki.noreply.org/noreply/TheOnionRouter/TorFAQ#FtpProxy">i tak
 powinieneś je ustawić</a>.) Powinieneś też wypełnić pola serwera SOCKS tak, by
 wskazywały bezpośrenio na Tor'a ("localhost", "9050" i socks5), by
 pokryć inne protokoły niż te cztery. Po wszystkim klinij "OK":</p>
<img alt="Konfiguracja serwerów proxy"
src="../img/screenshot-switchproxy-proxyconfig.jpg" width="430" height="434">
<p>Utworzyłeś etykietę "tor" dla serwera proxy, ale przeglądarka jeszcze jej nie używa.
 Kliknij na listę rozwijaną i wybierz "tor", jak pokazano:</p>
<img alt="Przełączanie się na Tor'a"
src="../img/screenshot-switchproxy-switch.jpg" width="671" height="558">
<p>Prawie gotowe. Kliknij "Zastosuj", by zmiany odniosły skutek:</p>
<img alt="Zastosuj"
src="../img/screenshot-switchproxy-apply.jpg" width="729" height="535">
<p>Koniec. Firefox przeładuje bieżącą stronę. Na tym przykładowym zrzucie ekranu,
 przeładował stronę i <a
 href="http://wiki.noreply.org/noreply/TheOnionRouter/TorFAQ#GoogleLanguage">akurat
 dostał niemiecki węzeł wyjściowy</a>:</p>
<img alt="Niemieckie google"
src="../img/screenshot-switchproxy-german.jpg" width="671" height="558">
<hr>
<a id="three"></a>
<h2><a class="anchor" href="#three">Krok 3: Sprawdzenie, czy wszystko działa</a></h2>
<br>
<p>Teraz Firefox korzysta z Privoxy jako serwera HTTP proxy, Privoxy używa
 Tor'a jako serwer proxy SOCKS4a, a Tor wykonuje Twoje połączenia do internetu.</p>
<p>W powyższym przykładzie było jasne, że wszystko działa, gdyż strona WWW pokazała
 się w innym języku. Jednak w innych przypadkach wolałbyś sprawdzić, że twoje
 ustawienia działają. Wykonaj
 <a href="../docs/tor-doc-win32.html.pl#verify">krok 3</a>
 w opisie instalacji Tor'a dla Windows lub
 <a href="../docs/tor-doc-osx.html.pl#verify">krok 3</a>
 w opisie instalacji Tor'a dla OS X.</p>
<p>Powinieneś jednak zdawać sobie sprawę z haczyka dotyczącego anonimowości:
 gdy przełączasz się z Tor'a na połączenie bezpośrednie (lub na odwrót),
 bieżąca strona zostanie domyślnie przeładowana, korzystając z nowych
 ustawień proxy. Dlatego przed przełączaniem się, upewnij się, że
 jesteś na stronie nie zawierającej żadnych istotnych informacji.
 (Możesz też zmienić to zachowanie w menu "Opcje | Preferencje" w SwitchProxy)</p>
<hr>
<p>Jeśli masz pomysły na ulepszenie tej strony, prosimy <a
href="../contact.html.pl">je do nas wysłać</a>. Dziękujemy!</p>
  </div><!-- #main -->
</div>
</div>
  <div class="bottom" id="bottom">
     <p>
     <i><a href="../contact.html.pl" class="smalllink">Webmaster</a></i> -
      Ostatnio zmodyfikowane: Sat Nov 4 23:14:55 2006
      -
      Ostatnio wygenerowane: Sun Nov 5 21:22:16 2006
     </p>
 <p>
 Ani deweloperzy Tor'a, ani EFF nie sprawdziły tłumaczenia tej strony pod względem dokładności
  i poprawności. Tłumaczenie może być przestarzałe lub niepoprawne. Oficjalna strona Tor'a jest
  po angielsku, pod adresem <a href="http://tor.eff.org/">http://tor.eff.org/</a>.
 </p>
     <p>
       Ta strona jest także dostępna w następujących językach:
       <a href="tor-switchproxy.html.en">English</a>, <a href="tor-switchproxy.html.it">Italiano</a>.<br>
       Jak ustawić <a href="http://www.debian.org/intro/cn#howtoset">domyślny język dokumentu</a>.
     </p>
  </div>
</body>
</html>

==> tor_0.1.1.26.orig.tar.gz: tor-0.1.1.26/doc/website/tor-switchproxy.html.pl <==
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN" "http://www.w3.org/TR/REC-html40/loose.dtd">
<html>
<head>
  <title>Tor: Instrukcje do instalacji SwitchProxy</title>
  <meta name="Author" content="Roger Dingledine">
  <meta http-equiv="content-type" content="text/html; charset=UTF-8">
  <link rel="stylesheet" type="text/css" href="../stylesheet.css">
  <link rel="shortcut icon" type="image/x-icon" href="../favicon.ico">
</head>
<body>
<div class="center">
<table class="banner" border="0" cellpadding="0" cellspacing="0" summary="">
    <tr>
        <td class="banner-left"></td>
        <td class="banner-middle">
	<a href="../index.html.pl">Strona główna</a>
<a href="../overview.html.pl">Wprowadzenie</a>
<a href="../download.html.pl">Pobieranie plików</a>
<a href="../documentation.html.pl">Dokumentacja</a>
<a href="../volunteer.html.pl">Wolontariusze</a>
<a href="../people.html.pl">Ludzie</a>
<a href="../donate.html.pl">Dotacje</a>
        </td>
        <td class="banner-right">
	<img src="../images/green-flagspace.png" alt="" width="24" height="16"> <a href="tor-switchproxy.html.en"><acronym title="English"><img src="../images/en.png" alt="English" width="24" height="16"></acronym></a> <img src="../images/green-flagspace.png" alt="" width="24" height="16"> <img src="../images/green-flagspace.png" alt="" width="24" height="16"> <a href="tor-switchproxy.html.it"><acronym title="Italiano"><img src="../images/it.png" alt="Italiano" width="24" height="16"></acronym></a> <img src="../images/green-flagspace.png" alt="" width="24" height="16"> <acronym title="polski"><img src="../images/pl.png" alt="polski" width="24" height="16"></acronym> <img src="../images/green-flagspace.png" alt="" width="24" height="16"> <img src="../images/green-flagspace.png" alt="" width="24" height="16"> <img src="../images/green-flagspace.png" alt="" width="24" height="16"> <img src="../images/green-flagspace.png" alt="" width="24" height="16">
        </td>
    </tr>
</table>
<div class="center">
<div class="main-column">
<p>Uwaga: SwitchProxy już nie jest polecanym rozszerzeniem do
 używania Tor'a w Firefox'ie. <b>Zamiast tego, powinieneś używać rozszerzenia <a
 href="http://freehaven.net/~squires/torbutton/">Torbutton</a>.</b>
 Zostawimy instrukcje do SwitchProxy dla tych, którzy wolą starszy
 (trudniejszy) sposób lub którzy mają bardziej złożone potrzeby, jak np.
 uruchamianie Tor'a na innym komputerze niż Firefox.</p>
<h1>Instalowanie SwitchProxy do współpracy z <a href="../index.html.pl">Tor'em</a></h1>
<hr>
<p>
SwitchProxy jest rozszerzeniem dla Firefox'a, które ułatwia przełączanie
 się między używaniem serwera Proxy a bezpośrednim łączeniem się ze
 stronami WWW.</p>
<p>Dzięki temu dokumentowi ustawisz SwitchProxy tak, by umożliwiało
 przełączanie się między używaniem Tor'a a połączeniem bezpośrednim.
 Zakładamy, że masz zainstalowanego i działającego Firefox'a.</p>
<p>Te zrzuty ekranu są dla użytkowników systemu Windows, ale
 SwitchProxy działa wszędzie tam, gdzie działa Firefox. Mamy nadzieję, że
 inni użytkownicy bez problemu będą nadążać.</p>
<hr>
<a id="zero"></a>
<h2><a class="anchor" href="#zero">Krok 0: Pobierz i zainstaluj Tor'a i Privoxy</a></h2>
<br>
<p>Zanim zaczniesz, musisz upewnić się, że 1) Tor jest uruchomiony i działa
 2) Privoxy jest uruchomione i działa, i 3) Privoxy jest skonfigurowane by
 używać Tor'a.</p>
<p>Użytkownicy Windows muszą wykonać <a
 href="../docs/tor-doc-win32.html.pl#installing">krok 1</a>
 w opisie instalacji Tor'a dla Windows, a użytkownicy MAC OS X muszą wykonać <a
 href="../docs/tor-doc-osx.html.pl#installing">krok 1</a>
 w opisie instalacji Tor'a dla MAC OS X, gdyż nasze paczki dla Win32 i OS X
 zawierają Privoxy i jest już ono skonfigurowane. Użytkownicy Linux/BSD/Unix powinni wykonać <a
 href="../docs/tor-doc-unix.html.pl#installing">krok 1</a>
 i <a href="../docs/tor-doc-unix.html.pl#privoxy">krok
 2</a> w opisie instalacji Tor'a dla systemów Unix.
</p>
<hr>
<a id="one"></a>
<h2><a class="anchor" href="#one">Krok 1: Pobranie i instalacja SwitchProxy</a></h2>
<br>
<p>SwitchProxy jest rozszerzeniem do Firefox'a, więc musisz przejść przez
 proces instalacji nowego rozszerzenia. Najpierw przejdź na stronę <a
 href="https://addons.mozilla.org/addon.php?id=125">SwitchProxy</a>.
 Na chwilę włącz JavaScript i kliknij "Instaluj" ("Install Now"):</p>
<img alt="Strona WWW SwitchProxy"
src="../img/screenshot-switchproxy-webpage.jpg" width="698" height="527">
<p>Pojawi się okno z prośbą o pozwolenie instalacji rozszerzenia. Kliknij
 przycisk "Zainstaluj":
</p>
<img alt="Ostrzeżenie przed instalacją rozszerzenia w Firefox'ie"
src="../img/screenshot-switchproxy-plugin-starting.jpg" width="405" height="359">
<p>Gdy instalator skończył pracę zamknij wszystkie okna Firefox'a i
 ponownie go uruchom.</p>
<img alt="Zakończenie instalacji roszerzenia"
src="../img/screenshot-switchproxy-plugin-finished.jpg" width="450" height="171">
<hr>
<a id="two"></a>
<h2><a class="anchor" href="#two">Krok 2: Konfiguracja SwitchProxy</a></h2>
<br>
<p>Po ponownym uruchomieniu Firefox'a zauważysz nowy pasek narzędzi, który
 pozwala na kontrolę serwerów Proxy. Teraz ustawimy konfigurację Proxy dla
 Tor'a. Kliknij "Dodaj" ("Add") na nowym pasku narzędzi Proxy:</p>
<img alt="Nowy pasek narzędzi"
src="../img/screenshot-switchproxy-toolbar.jpg" width="651" height="535">
<p>Zostaniesz zapytany o typ serwera proxy. Wybierz "Standardowy".
 (Jest też typ "anonimowy", który używa istniejących anonimowych serwerów proxy.
 Nie używaj tego typu, gdyż te inne "anonimowe" serwery proxy <a
 href="http://wiki.noreply.org/noreply/TheOnionRouter/TorFAQ#ComparisonProxyAggregators">dają
 o wiele gorsze zabezpieczenia niż Tor</a>.)
</p>
<img alt="Standardowe proxy"
src="../img/screenshot-switchproxy-proxytype.jpg" width="309" height="208">
<p>Teraz zobaczysz standardowe okno konfiguracji serwerów proxy w Firefox'ie.
 Nadaj tej konfiguracji nazwę (etykietę) "tor". Potem wpisz "localhost" i
 "8118" do czterech pierwszych protokołów, by skierować je na Privoxy, jak
 pokazano. (Nawet mimo iż Privoxy nie obsluguje FTP i Gophera, <a
 href="http://wiki.noreply.org/noreply/TheOnionRouter/TorFAQ#FtpProxy">i tak
 powinieneś je ustawić</a>.) Powinieneś też wypełnić pola serwera SOCKS tak, by
 wskazywały bezpośrenio na Tor'a ("localhost", "9050" i socks5), by
 pokryć inne protokoły niż te cztery. Po wszystkim klinij "OK":</p>
<img alt="Konfiguracja serwerów proxy"
src="../img/screenshot-switchproxy-proxyconfig.jpg" width="430" height="434">
<p>Utworzyłeś etykietę "tor" dla serwera proxy, ale przeglądarka jeszcze jej nie używa.
 Kliknij na listę rozwijaną i wybierz "tor", jak pokazano:</p>
<img alt="Przełączanie się na Tor'a"
src="../img/screenshot-switchproxy-switch.jpg" width="671" height="558">
<p>Prawie gotowe. Kliknij "Zastosuj", by zmiany odniosły skutek:</p>
<img alt="Zastosuj"
src="../img/screenshot-switchproxy-apply.jpg" width="729" height="535">
<p>Koniec. Firefox przeładuje bieżącą stronę. Na tym przykładowym zrzucie ekranu,
 przeładował stronę i <a
 href="http://wiki.noreply.org/noreply/TheOnionRouter/TorFAQ#GoogleLanguage">akurat
 dostał niemiecki węzeł wyjściowy</a>:</p>
<img alt="Niemieckie google"
src="../img/screenshot-switchproxy-german.jpg" width="671" height="558">
<hr>
<a id="three"></a>
<h2><a class="anchor" href="#three">Krok 3: Sprawdzenie, czy wszystko działa</a></h2>
<br>
<p>Teraz Firefox korzysta z Privoxy jako serwera HTTP proxy, Privoxy używa
 Tor'a jako serwer proxy SOCKS4a, a Tor wykonuje Twoje połączenia do internetu.</p>
<p>W powyższym przykładzie było jasne, że wszystko działa, gdyż strona WWW pokazała
 się w innym języku. Jednak w innych przypadkach wolałbyś sprawdzić, że twoje
 ustawienia działają. Wykonaj
 <a href="../docs/tor-doc-win32.html.pl#verify">krok 3</a>
 w opisie instalacji Tor'a dla Windows lub
 <a href="../docs/tor-doc-osx.html.pl#verify">krok 3</a>
 w opisie instalacji Tor'a dla OS X.</p>
<p>Powinieneś jednak zdawać sobie sprawę z haczyka dotyczącego anonimowości:
 gdy przełączasz się z Tor'a na połączenie bezpośrednie (lub na odwrót),
 bieżąca strona zostanie domyślnie przeładowana, korzystając z nowych
 ustawień proxy. Dlatego przed przełączaniem się, upewnij się, że
 jesteś na stronie nie zawierającej żadnych istotnych informacji.
 (Możesz też zmienić to zachowanie w menu "Opcje | Preferencje" w SwitchProxy)</p>
<hr>
<p>Jeśli masz pomysły na ulepszenie tej strony, prosimy <a
href="../contact.html.pl">je do nas wysłać</a>. Dziękujemy!</p>
  </div><!-- #main -->
</div>
</div>
  <div class="bottom" id="bottom">
     <p>
     <i><a href="../contact.html.pl" class="smalllink">Webmaster</a></i> -
      Ostatnio zmodyfikowane: Sat Nov 4 23:14:55 2006
      -
      Ostatnio wygenerowane: Tue Dec 5 11:41:50 2006
     </p>
 <p>
 Ani deweloperzy Tor'a, ani EFF nie sprawdziły tłumaczenia tej strony pod względem dokładności
  i poprawności. Tłumaczenie może być przestarzałe lub niepoprawne. Oficjalna strona Tor'a jest
  po angielsku, pod adresem <a href="http://tor.eff.org/">http://tor.eff.org/</a>.
 </p>
     <p>
       Ta strona jest także dostępna w następujących językach:
       <a href="tor-switchproxy.html.en">English</a>, <a href="tor-switchproxy.html.it">Italiano</a>.<br>
       Jak ustawić <a href="http://www.debian.org/intro/cn#howtoset">domyślny język dokumentu</a>.
     </p>
  </div>
</body>
</html>
